// ignore_for_file: require_trailing_commas

import 'package:flutter/widgets.dart';
import 'package:spot/spot.dart';

/// Matchers for [Image] auto-generated by spot
///
/// ```dart
/// spot<Image>().printMatchers(propNameOverrides: (MapEntry('this.excludeFromSemantics': 'excludeFromSemantics')));
/// ```
/// Matchers for the properties of [Image] provided via [Diagnosticable.debugFillProperties]
extension ImageMatcher on WidgetMatcher<Image> {
  /// Expects that image of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasImageWhere(MatchProp<ImageProvider<Object>> match) {
    return hasDiagnosticProp<ImageProvider<Object>>('image', match);
  }

  /// Expects that image of [Image] equals (==) [value]
  WidgetMatcher<Image> hasImage(ImageProvider<Object>? value) {
    return hasDiagnosticProp<ImageProvider<Object>>(
        'image', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that frameBuilder of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasFrameBuilderWhere(MatchProp<Function> match) {
    return hasDiagnosticProp<Function>('frameBuilder', match);
  }

  /// Expects that frameBuilder of [Image] equals (==) [value]
  WidgetMatcher<Image> hasFrameBuilder(Function? value) {
    return hasDiagnosticProp<Function>(
        'frameBuilder', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that loadingBuilder of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasLoadingBuilderWhere(MatchProp<Function> match) {
    return hasDiagnosticProp<Function>('loadingBuilder', match);
  }

  /// Expects that loadingBuilder of [Image] equals (==) [value]
  WidgetMatcher<Image> hasLoadingBuilder(Function? value) {
    return hasDiagnosticProp<Function>('loadingBuilder',
        (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that width of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasWidthWhere(MatchProp<double> match) {
    return hasDiagnosticProp<double>('width', match);
  }

  /// Expects that width of [Image] equals (==) [value]
  WidgetMatcher<Image> hasWidth(double? value) {
    return hasDiagnosticProp<double>(
        'width', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that height of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasHeightWhere(MatchProp<double> match) {
    return hasDiagnosticProp<double>('height', match);
  }

  /// Expects that height of [Image] equals (==) [value]
  WidgetMatcher<Image> hasHeight(double? value) {
    return hasDiagnosticProp<double>(
        'height', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that color of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasColorWhere(MatchProp<Color> match) {
    return hasDiagnosticProp<Color>('color', match);
  }

  /// Expects that color of [Image] equals (==) [value]
  WidgetMatcher<Image> hasColor(Color? value) {
    return hasDiagnosticProp<Color>(
        'color', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that opacity of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasOpacityWhere(MatchProp<Animation<double>?> match) {
    return hasDiagnosticProp<Animation<double>?>('opacity', match);
  }

  /// Expects that opacity of [Image] equals (==) [value]
  WidgetMatcher<Image> hasOpacity(Animation<double>? value) {
    return hasDiagnosticProp<Animation<double>?>(
        'opacity', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that colorBlendMode of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasColorBlendModeWhere(MatchProp<BlendMode> match) {
    return hasDiagnosticProp<BlendMode>('colorBlendMode', match);
  }

  /// Expects that colorBlendMode of [Image] equals (==) [value]
  WidgetMatcher<Image> hasColorBlendMode(BlendMode? value) {
    return hasDiagnosticProp<BlendMode>('colorBlendMode',
        (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that fit of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasFitWhere(MatchProp<BoxFit> match) {
    return hasDiagnosticProp<BoxFit>('fit', match);
  }

  /// Expects that fit of [Image] equals (==) [value]
  WidgetMatcher<Image> hasFit(BoxFit? value) {
    return hasDiagnosticProp<BoxFit>(
        'fit', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that alignment of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasAlignmentWhere(MatchProp<AlignmentGeometry> match) {
    return hasDiagnosticProp<AlignmentGeometry>('alignment', match);
  }

  /// Expects that alignment of [Image] equals (==) [value]
  WidgetMatcher<Image> hasAlignment(AlignmentGeometry? value) {
    return hasDiagnosticProp<AlignmentGeometry>(
        'alignment', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that repeat of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasRepeatWhere(MatchProp<ImageRepeat> match) {
    return hasDiagnosticProp<ImageRepeat>('repeat', match);
  }

  /// Expects that repeat of [Image] equals (==) [value]
  WidgetMatcher<Image> hasRepeat(ImageRepeat? value) {
    return hasDiagnosticProp<ImageRepeat>(
        'repeat', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that centerSlice of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasCenterSliceWhere(MatchProp<Rect> match) {
    return hasDiagnosticProp<Rect>('centerSlice', match);
  }

  /// Expects that centerSlice of [Image] equals (==) [value]
  WidgetMatcher<Image> hasCenterSlice(Rect? value) {
    return hasDiagnosticProp<Rect>(
        'centerSlice', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that matchTextDirection of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasMatchTextDirectionWhere(MatchProp<bool> match) {
    return hasDiagnosticProp<bool>('matchTextDirection', match);
  }

  /// Expects that matchTextDirection of [Image] equals (==) [value]
  WidgetMatcher<Image> hasMatchTextDirection(bool? value) {
    return hasDiagnosticProp<bool>('matchTextDirection',
        (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that semanticLabel of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasSemanticLabelWhere(MatchProp<String> match) {
    return hasDiagnosticProp<String>('semanticLabel', match);
  }

  /// Expects that semanticLabel of [Image] equals (==) [value]
  WidgetMatcher<Image> hasSemanticLabel(String? value) {
    return hasDiagnosticProp<String>('semanticLabel',
        (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that excludeFromSemantics of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasExcludeFromSemanticsWhere(MatchProp<bool> match) {
    return hasDiagnosticProp<bool>('this.excludeFromSemantics', match);
  }

  /// Expects that excludeFromSemantics of [Image] equals (==) [value]
  WidgetMatcher<Image> hasExcludeFromSemantics(bool? value) {
    return hasDiagnosticProp<bool>('this.excludeFromSemantics',
        (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Expects that filterQuality of [Image] matches the condition in [match]
  WidgetMatcher<Image> hasFilterQualityWhere(MatchProp<FilterQuality> match) {
    return hasDiagnosticProp<FilterQuality>('filterQuality', match);
  }

  /// Expects that filterQuality of [Image] equals (==) [value]
  WidgetMatcher<Image> hasFilterQuality(FilterQuality? value) {
    return hasDiagnosticProp<FilterQuality>('filterQuality',
        (it) => value == null ? it.isNull() : it.equals(value));
  }
}

/// Allows filtering [Image] by the properties provided via [Diagnosticable.debugFillProperties]
extension ImageSelector on WidgetSelector<Image> {
  /// Creates a [WidgetSelector] that finds all [Image] where image matches the condition
  WidgetSelector<Image> whereImage(MatchProp<ImageProvider<Object>> match) {
    return withDiagnosticProp<ImageProvider<Object>>('image', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where image equals (==) [value]
  WidgetSelector<Image> withImage(ImageProvider<Object>? value) {
    return withDiagnosticProp<ImageProvider<Object>>(
        'image', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where frameBuilder matches the condition
  WidgetSelector<Image> whereFrameBuilder(MatchProp<Function> match) {
    return withDiagnosticProp<Function>('frameBuilder', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where frameBuilder equals (==) [value]
  WidgetSelector<Image> withFrameBuilder(Function? value) {
    return withDiagnosticProp<Function>(
        'frameBuilder', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where loadingBuilder matches the condition
  WidgetSelector<Image> whereLoadingBuilder(MatchProp<Function> match) {
    return withDiagnosticProp<Function>('loadingBuilder', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where loadingBuilder equals (==) [value]
  WidgetSelector<Image> withLoadingBuilder(Function? value) {
    return withDiagnosticProp<Function>('loadingBuilder',
        (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where width matches the condition
  WidgetSelector<Image> whereWidth(MatchProp<double> match) {
    return withDiagnosticProp<double>('width', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where width equals (==) [value]
  WidgetSelector<Image> withWidth(double? value) {
    return withDiagnosticProp<double>(
        'width', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where height matches the condition
  WidgetSelector<Image> whereHeight(MatchProp<double> match) {
    return withDiagnosticProp<double>('height', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where height equals (==) [value]
  WidgetSelector<Image> withHeight(double? value) {
    return withDiagnosticProp<double>(
        'height', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where color matches the condition
  WidgetSelector<Image> whereColor(MatchProp<Color> match) {
    return withDiagnosticProp<Color>('color', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where color equals (==) [value]
  WidgetSelector<Image> withColor(Color? value) {
    return withDiagnosticProp<Color>(
        'color', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where opacity matches the condition
  WidgetSelector<Image> whereOpacity(MatchProp<Animation<double>?> match) {
    return withDiagnosticProp<Animation<double>?>('opacity', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where opacity equals (==) [value]
  WidgetSelector<Image> withOpacity(Animation<double>? value) {
    return withDiagnosticProp<Animation<double>?>(
        'opacity', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where colorBlendMode matches the condition
  WidgetSelector<Image> whereColorBlendMode(MatchProp<BlendMode> match) {
    return withDiagnosticProp<BlendMode>('colorBlendMode', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where colorBlendMode equals (==) [value]
  WidgetSelector<Image> withColorBlendMode(BlendMode? value) {
    return withDiagnosticProp<BlendMode>('colorBlendMode',
        (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where fit matches the condition
  WidgetSelector<Image> whereFit(MatchProp<BoxFit> match) {
    return withDiagnosticProp<BoxFit>('fit', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where fit equals (==) [value]
  WidgetSelector<Image> withFit(BoxFit? value) {
    return withDiagnosticProp<BoxFit>(
        'fit', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where alignment matches the condition
  WidgetSelector<Image> whereAlignment(MatchProp<AlignmentGeometry> match) {
    return withDiagnosticProp<AlignmentGeometry>('alignment', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where alignment equals (==) [value]
  WidgetSelector<Image> withAlignment(AlignmentGeometry? value) {
    return withDiagnosticProp<AlignmentGeometry>(
        'alignment', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where repeat matches the condition
  WidgetSelector<Image> whereRepeat(MatchProp<ImageRepeat> match) {
    return withDiagnosticProp<ImageRepeat>('repeat', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where repeat equals (==) [value]
  WidgetSelector<Image> withRepeat(ImageRepeat? value) {
    return withDiagnosticProp<ImageRepeat>(
        'repeat', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where centerSlice matches the condition
  WidgetSelector<Image> whereCenterSlice(MatchProp<Rect> match) {
    return withDiagnosticProp<Rect>('centerSlice', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where centerSlice equals (==) [value]
  WidgetSelector<Image> withCenterSlice(Rect? value) {
    return withDiagnosticProp<Rect>(
        'centerSlice', (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where matchTextDirection matches the condition
  WidgetSelector<Image> whereMatchTextDirection(MatchProp<bool> match) {
    return withDiagnosticProp<bool>('matchTextDirection', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where matchTextDirection equals (==) [value]
  WidgetSelector<Image> withMatchTextDirection(bool? value) {
    return withDiagnosticProp<bool>('matchTextDirection',
        (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where semanticLabel matches the condition
  WidgetSelector<Image> whereSemanticLabel(MatchProp<String> match) {
    return withDiagnosticProp<String>('semanticLabel', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where semanticLabel equals (==) [value]
  WidgetSelector<Image> withSemanticLabel(String? value) {
    return withDiagnosticProp<String>('semanticLabel',
        (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where excludeFromSemantics matches the condition
  WidgetSelector<Image> whereExcludeFromSemantics(MatchProp<bool> match) {
    return withDiagnosticProp<bool>('this.excludeFromSemantics', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where excludeFromSemantics equals (==) [value]
  WidgetSelector<Image> withExcludeFromSemantics(bool? value) {
    return withDiagnosticProp<bool>('this.excludeFromSemantics',
        (it) => value == null ? it.isNull() : it.equals(value));
  }

  /// Creates a [WidgetSelector] that finds all [Image] where filterQuality matches the condition
  WidgetSelector<Image> whereFilterQuality(MatchProp<FilterQuality> match) {
    return withDiagnosticProp<FilterQuality>('filterQuality', match);
  }

  /// Creates a [WidgetSelector] that finds all [Image] where filterQuality equals (==) [value]
  WidgetSelector<Image> withFilterQuality(FilterQuality? value) {
    return withDiagnosticProp<FilterQuality>('filterQuality',
        (it) => value == null ? it.isNull() : it.equals(value));
  }
}
